@@ -1,7 +1,7 @@
 /*
  * SweetHome3DBootstrap.java 2 sept. 07
  *
- * Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ public class SweetHome3DBootstrap {
         "iText-2.1.5.jar", // Jars included in Sweet Home 3D executable jar file 
         "freehep-vectorgraphics-svg-2.1.1.jar",
         "Loader3DS1_2u.jar",
-        "sunflow-0.07.3f.jar",
+        "sunflow-0.07.3g.jar",
         "jmf.jar",
         "jnlp.jar",
         "j3dcore.jar", // Main Java 3D jars
