@@ -1,7 +1,7 @@
 /*
  * AppletApplication.java 11 Oct 2008
  *
- * Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,7 +39,6 @@ import javax.jnlp.BasicService;
 import javax.jnlp.ServiceManager;
 import javax.jnlp.ServiceManagerStub;
 import javax.jnlp.UnavailableServiceException;
-import javax.media.j3d.IllegalRenderingStateException;
 import javax.swing.AbstractButton;
 import javax.swing.Action;
 import javax.swing.BorderFactory;
@@ -127,6 +126,12 @@ public class AppletApplication extends HomeApplication {
 
     URL codeBase = applet.getCodeBase();
 
+    // Force offscreen in 3D view under Plugin 2 and Mac OS X
+    System.setProperty("com.eteks.sweethome3d.j3d.useOffScreen3DView", 
+        String.valueOf(OperatingSystem.isMacOSX()            
+            && applet.getAppletContext() != null
+            && applet.getAppletContext().getClass().getName().startsWith("sun.plugin2.applet.Plugin2Manager")));
+    
     // If Sweet Home 3D applet is launched from outside of Java Web Start or basic service is unavailable
     boolean serviceManagerAvailable = ServiceManager.getServiceNames() != null; 
     if (serviceManagerAvailable) {
@@ -168,9 +173,14 @@ public class AppletApplication extends HomeApplication {
                     controller.open(defaultHome);
                   }
                 }
-              } catch (IllegalRenderingStateException ex) {
-                ex.printStackTrace();
-                show3DError();
+              } catch (IllegalStateException ex) {
+                // Check exception by class name to avoid a mandatory bind to Java 3D
+                if ("javax.media.j3d.IllegalRenderingStateException".equals(ex.getClass().getName())) {
+                  ex.printStackTrace();
+                  show3DError();
+                } else {
+                  throw ex;
+                }
               }
               break;
           }
@@ -222,8 +232,10 @@ public class AppletApplication extends HomeApplication {
     System.gc();
     // Stop managers threads
     IconManager.getInstance().clear();
-    TextureManager.getInstance().clear();
-    ModelManager.getInstance().clear();
+    if (!"true".equalsIgnoreCase(System.getProperty("com.eteks.sweethome3d.no3D"))) { 
+      TextureManager.getInstance().clear();
+      ModelManager.getInstance().clear();
+    }
     // Delete temporary files
     OperatingSystem.deleteTemporaryFiles();
   }
@@ -334,10 +346,13 @@ public class AppletApplication extends HomeApplication {
     
     // As the applet has no menu, activate accelerators directly on home view
     for (HomeView.ActionType actionType : HomeView.ActionType.values()) {
-      ResourceAction.MenuItemAction menuAction = new ResourceAction.MenuItemAction(homeView.getActionMap().get(actionType));
-      KeyStroke accelerator = (KeyStroke)menuAction.getValue(Action.ACCELERATOR_KEY);
-      if (accelerator != null) {
-        homeView.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(accelerator, actionType);
+      Action action = homeView.getActionMap().get(actionType);
+      if (action != null) {
+        ResourceAction.MenuItemAction menuAction = new ResourceAction.MenuItemAction(action);
+        KeyStroke accelerator = (KeyStroke)menuAction.getValue(Action.ACCELERATOR_KEY);
+        if (accelerator != null) {
+          homeView.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(accelerator, actionType);
+        }
       }
     }
     
@@ -357,19 +372,19 @@ public class AppletApplication extends HomeApplication {
     toolBar.removeAll();
     // Add New, Open, Save, Save as buttons if they are enabled
     Action newHomeAction = getToolBarAction(homeView, HomeView.ActionType.NEW_HOME);
-    if (newHomeAction.isEnabled()) {
+    if (newHomeAction != null && newHomeAction.isEnabled()) {
       toolBar.add(newHomeAction);
     }
     Action openAction = getToolBarAction(homeView, HomeView.ActionType.OPEN);
-    if (openAction.isEnabled()) {
+    if (openAction != null && openAction.isEnabled()) {
       toolBar.add(openAction);
     }
     Action saveAction = getToolBarAction(homeView, HomeView.ActionType.SAVE);
-    if (saveAction.isEnabled()) {
+    if (saveAction != null && saveAction.isEnabled()) {
       toolBar.add(saveAction);
     }
     Action saveAsAction = getToolBarAction(homeView, HomeView.ActionType.SAVE_AS);
-    if (saveAsAction.isEnabled()) {
+    if (saveAsAction != null && saveAsAction.isEnabled()) {
       toolBar.add(saveAsAction);
     }
     
@@ -388,26 +403,38 @@ public class AppletApplication extends HomeApplication {
     if (toolBar.getComponentCount() > 0) {
       toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
     }
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.PAGE_SETUP));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.PRINT));
-    if (getAppletBooleanParameter(this.applet, ENABLE_PRINT_TO_PDF) && !OperatingSystem.isMacOSX()) {
+    addToolBarAction(homeView, HomeView.ActionType.PAGE_SETUP, toolBar);
+    addToolBarAction(homeView, HomeView.ActionType.PRINT, toolBar);
+    Action printToPdfAction = getToolBarAction(homeView, HomeView.ActionType.PRINT_TO_PDF);
+    if (printToPdfAction != null 
+        && getAppletBooleanParameter(this.applet, ENABLE_PRINT_TO_PDF) 
+        && !OperatingSystem.isMacOSX()) {
       controller.getView().setEnabled(HomeView.ActionType.PRINT_TO_PDF, true);
-      toolBar.add(getToolBarAction(homeView, HomeView.ActionType.PRINT_TO_PDF));
+      toolBar.add(printToPdfAction);
+    }
+    Action preferencesAction = getToolBarAction(homeView, HomeView.ActionType.PREFERENCES);
+    if (preferencesAction != null) {
+      toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
+      toolBar.add(preferencesAction);
     }
-    toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.PREFERENCES));
     toolBar.addSeparator();
 
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.UNDO));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.REDO));
+    addToolBarAction(homeView, HomeView.ActionType.UNDO, toolBar);
+    addToolBarAction(homeView, HomeView.ActionType.REDO, toolBar);
     toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.CUT));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.COPY));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.PASTE));
+    addToolBarAction(homeView, HomeView.ActionType.CUT, toolBar);
+    addToolBarAction(homeView, HomeView.ActionType.COPY, toolBar);
+    addToolBarAction(homeView, HomeView.ActionType.PASTE, toolBar);
     toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.DELETE));
+    addToolBarAction(homeView, HomeView.ActionType.DELETE, toolBar);
     toolBar.addSeparator();
 
+    Action addHomeFurnitureAction = getToolBarAction(homeView, HomeView.ActionType.ADD_HOME_FURNITURE);
+    if (addHomeFurnitureAction != null) {
+      toolBar.add(addHomeFurnitureAction);
+      toolBar.addSeparator();
+    }
+    
     final JToggleButton selectToggleButton = 
         new JToggleButton(getToolBarAction(homeView, HomeView.ActionType.SELECT));
     selectToggleButton.setSelected(true);
@@ -449,14 +476,17 @@ public class AppletApplication extends HomeApplication {
         });
     toolBar.add(Box.createRigidArea(new Dimension(2, 2)));
     
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.ZOOM_OUT));
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.ZOOM_IN));
+    addToolBarAction(homeView, HomeView.ActionType.ZOOM_OUT, toolBar);
+    addToolBarAction(homeView, HomeView.ActionType.ZOOM_IN, toolBar);
 
-    boolean enableCreatePhoto = getAppletBooleanParameter(this.applet, ENABLE_CREATE_PHOTO);
-    controller.getView().setEnabled(HomeView.ActionType.CREATE_PHOTO, enableCreatePhoto);
-    if (enableCreatePhoto) {
-      toolBar.addSeparator();
-      toolBar.add(getToolBarAction(homeView, HomeView.ActionType.CREATE_PHOTO));
+    Action createPhotoAction = getToolBarAction(homeView, HomeView.ActionType.CREATE_PHOTO);
+    if (createPhotoAction != null) {
+      boolean enableCreatePhoto = getAppletBooleanParameter(this.applet, ENABLE_CREATE_PHOTO);
+      controller.getView().setEnabled(HomeView.ActionType.CREATE_PHOTO, enableCreatePhoto);
+      if (enableCreatePhoto) {
+        toolBar.addSeparator();
+        toolBar.add(createPhotoAction);
+      }
     }
 
     // Add plug-in buttons
@@ -467,8 +497,11 @@ public class AppletApplication extends HomeApplication {
       }
     }
     
-    toolBar.addSeparator();
-    toolBar.add(getToolBarAction(homeView, HomeView.ActionType.ABOUT));
+    Action aboutAction = getToolBarAction(homeView, HomeView.ActionType.ABOUT);
+    if (aboutAction != null) {
+      toolBar.addSeparator();
+      toolBar.add(aboutAction);
+    }
     
     controller.getView().setEnabled(HomeView.ActionType.EXPORT_TO_SVG, 
         getAppletBooleanParameter(this.applet, ENABLE_EXPORT_TO_SVG));
@@ -482,12 +515,25 @@ public class AppletApplication extends HomeApplication {
     
     return controller;
   }
+  
+  /**
+   * Adds the action matching the given <code>actionType</code> to the tool bar if it exists.
+   */
+  private void addToolBarAction(JComponent homeView, HomeView.ActionType actionType, JToolBar toolBar) {
+    Action action = getToolBarAction(homeView, actionType);
+    if (action != null) {
+      toolBar.add(action);
+    }
+  }
 
   /**
    * Returns an action decorated for tool bar buttons.
    */
   private Action getToolBarAction(JComponent homeView, HomeView.ActionType actionType) {
-    return new ResourceAction.ToolBarAction(homeView.getActionMap().get(actionType));
+    Action action = homeView.getActionMap().get(actionType);    
+    return action != null 
+        ? new ResourceAction.ToolBarAction(action)
+        : null;
   }
   
   /**
@@ -613,20 +659,22 @@ public class AppletApplication extends HomeApplication {
    * to avoid default System exit in case of error during 3D rendering. 
    */
   private void addComponent3DRenderingErrorObserver() {
-    // Instead of adding a RenderingErrorListener directly to VirtualUniverse, 
-    // we add it through Canvas3DManager, because offscreen rendering needs to check 
-    // rendering errors with its own RenderingErrorListener
-    Component3DManager.getInstance().setRenderingErrorObserver(
-        new Component3DManager.RenderingErrorObserver() {
-          public void errorOccured(int errorCode, String errorMessage) {
-            System.err.print("Error in Java 3D : " + errorCode + " " + errorMessage);
-            EventQueue.invokeLater(new Runnable() {
-                public void run() {
-                  show3DError();
-                }
-              });
-          }
-        });
+    if (!"true".equalsIgnoreCase(System.getProperty("com.eteks.sweethome3d.no3D"))) { 
+      // Instead of adding a RenderingErrorListener directly to VirtualUniverse, 
+      // we add it through Component3DManager, because offscreen rendering needs to check 
+      // rendering errors with its own RenderingErrorListener
+      Component3DManager.getInstance().setRenderingErrorObserver(
+          new Component3DManager.RenderingErrorObserver() {
+            public void errorOccured(int errorCode, String errorMessage) {
+              System.err.print("Error in Java 3D : " + errorCode + " " + errorMessage);
+              EventQueue.invokeLater(new Runnable() {
+                  public void run() {
+                    show3DError();
+                  }
+                });
+            }
+          });
+    }
   }
 
   /**
