@@ -1,7 +1,7 @@
 /*
  * SweetHome3DApplet.java 10 oct. 2008
  *
- * Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -320,7 +320,8 @@ public class SweetHome3DApplet extends JApplet {
         showError(getLocalizedString("signatureError"));
       } else {
         showError("<html>" + getLocalizedString("startError") 
-            + "<br>Exception" + ex.getClass().getName() + " " + ex.getMessage());
+            + "<br>Exception " + ex.getClass().getName() 
+            + (ex.getMessage() != null ? " " + ex.getMessage() : ""));
         ex.printStackTrace();
       }
     }
