@@ -1,7 +1,7 @@
 /*
  * Canvas3DManager.java 25 oct. 07
  *
- * Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
  */
 package com.eteks.sweethome3d.j3d;
 
+import java.awt.GraphicsConfigTemplate;
 import java.awt.GraphicsConfiguration;
 import java.awt.GraphicsEnvironment;
 import java.awt.image.BufferedImage;
@@ -58,15 +59,30 @@ public class Component3DManager {
 
 
   private Component3DManager() {
-    // Retrieve graphics configuration once 
-    GraphicsConfigTemplate3D gc = new GraphicsConfigTemplate3D();
-    // Try to get antialiasing
-    gc.setSceneAntialiasing(GraphicsConfigTemplate3D.PREFERRED);
-    this.configuration = GraphicsEnvironment.getLocalGraphicsEnvironment().
-            getDefaultScreenDevice().getBestConfiguration(gc);
-    if (this.configuration == null) {
+    if (!GraphicsEnvironment.isHeadless()) {
+      // Retrieve graphics configuration once 
+      GraphicsConfigTemplate3D template = new GraphicsConfigTemplate3D();
+      // Try to get antialiasing
+      template.setSceneAntialiasing(GraphicsConfigTemplate3D.PREFERRED);
+      
+      // From http://www.java.net/node/683852
+      // Check if the user has set the Java 3D stereo option.
+      String stereo = System.getProperty("j3d.stereo");
+      if (stereo != null) {
+        if ("REQUIRED".equals(stereo))
+          template.setStereo(GraphicsConfigTemplate.REQUIRED);
+        else if ("PREFERRED".equals(stereo))
+          template.setStereo(GraphicsConfigTemplate.PREFERRED);
+      }
+      
       this.configuration = GraphicsEnvironment.getLocalGraphicsEnvironment().
-          getDefaultScreenDevice().getBestConfiguration(new GraphicsConfigTemplate3D());
+              getDefaultScreenDevice().getBestConfiguration(template);
+      if (this.configuration == null) {
+        this.configuration = GraphicsEnvironment.getLocalGraphicsEnvironment().
+            getDefaultScreenDevice().getBestConfiguration(new GraphicsConfigTemplate3D());
+      }
+    } else {
+      this.offScreenImageSupported = Boolean.FALSE;
     }
   }
   
