@@ -1,7 +1,7 @@
 /*
  * OBJWriter.java 18 sept. 2008
  *
- * Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -376,11 +376,8 @@ public class OBJWriter extends FilterWriter {
                 File textureFile = this.textures.get(texture);
                 if (textureFile == null) {
                   // Store texture
-                  String fileFormat = texture.getFormat() == Texture.RGBA 
-                      ? "png"
-                      : "jpg";
                   textureFile = new File(this.mtlFileName.substring(0, this.mtlFileName.length() - 4) 
-                      + "_" + appearanceName + "." + fileFormat);
+                      + "_" + appearanceName + ".png");
                   this.textures.put(texture, textureFile);
                 }
               }
@@ -442,9 +439,11 @@ public class OBJWriter extends FilterWriter {
       int [] vertexIndexSubstitutes = new int [geometryArray.getVertexCount()];
       
       boolean normalsDefined = (geometryArray.getVertexFormat() & GeometryArray.NORMALS) != 0;
+      Map<Vector3f, Integer> previousNormalIndices = null;
       StringBuilder normalsBuffer;
       if (normalsDefined) {
-        normalsBuffer = new StringBuilder(geometryArray.getVertexCount() * 3 * 10); 
+        normalsBuffer = new StringBuilder(geometryArray.getVertexCount() * 3 * 10);
+        previousNormalIndices = new HashMap<Vector3f, Integer>(this.normalIndices);
       } else {
         normalsBuffer = null;
       }
@@ -589,6 +588,8 @@ public class OBJWriter extends FilterWriter {
       if (normalsDefined) {
         // Write normals only if they all contain valid values 
         out.write(normalsBuffer.toString());
+      } else if (previousNormalIndices != null) {
+        this.normalIndices = previousNormalIndices;
       }
 
       checkCurrentThreadIsntInterrupted();
@@ -1226,10 +1227,7 @@ public class OBJWriter extends FilterWriter {
         Texture texture = textureEntry.getKey();
         ImageComponent2D imageComponent = (ImageComponent2D)texture.getImage(0);
         RenderedImage image = imageComponent.getRenderedImage();
-        String fileFormat = texture.getFormat() == Texture.RGBA 
-            ? "png"
-            : "jpg";
-        ImageIO.write(image, fileFormat, textureEntry.getValue());        
+        ImageIO.write(image, "png", textureEntry.getValue());        
       }
     } finally {
       if (writer != null) {
