@@ -1,7 +1,7 @@
 /*
  * PhotoRenderer.java 22 janv. 2009
  *
- * Copyright (c) 2009 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2009 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@
  */
 package com.eteks.sweethome3d.j3d;
 
+import java.awt.AlphaComposite;
 import java.awt.EventQueue;
 import java.awt.Graphics2D;
 import java.awt.geom.Point2D;
@@ -125,7 +126,7 @@ public class PhotoRenderer {
   private boolean useAmbientOcclusion;
   private String sunSkyLightName;
   private String sunLightName;
-  private final Map<Texture, String> textureImagesCache = new HashMap<Texture, String>();
+  private final Map<TransparentTextureKey, String> textureImagesCache = new HashMap<TransparentTextureKey, String>();
   private Thread renderingThread;
 
   static {
@@ -209,8 +210,8 @@ public class PhotoRenderer {
       Graphics2D g2D = (Graphics2D)imageBaseLightImage.getGraphics();
       g2D.drawRenderedImage(skyImage, null);
       g2D.dispose();
-      File imageFile = OperatingSystem.createTemporaryFile("ibl", ".jpg");
-      ImageIO.write(imageBaseLightImage, "JPEG", imageFile);
+      File imageFile = OperatingSystem.createTemporaryFile("ibl", ".png");
+      ImageIO.write(imageBaseLightImage, "png", imageFile);
       
       this.sunflow.parameter("texture", imageFile.getAbsolutePath());
       this.sunflow.parameter("center", new Vector3(-1, 0, 0));
@@ -525,7 +526,7 @@ public class PhotoRenderer {
           ? appearance.getRenderingAttributes() : null;
       TransparencyAttributes transparencyAttributes = appearance != null 
           ? appearance.getTransparencyAttributes() : null;
-      // Ignore invisible shapes and fully transparent shapes without a texture 
+      // Ignore invisible shapes and fully transparency shapes without a texture 
       if ((renderingAttributes == null
               || renderingAttributes.getVisible())
           && (transparencyAttributes == null
@@ -1140,19 +1141,40 @@ public class PhotoRenderer {
       }
       this.sunflow.shader(appearanceName, "mirror");
     } else if (texture != null) {
-      String imagePath = texture.getUserData() instanceof URL
-          ? texture.getUserData().toString()
-          : this.textureImagesCache.get(texture);
+      // Check shape transparency 
+      TransparencyAttributes transparencyAttributes = appearance.getTransparencyAttributes();
+      float transparency;
+      if (transparencyAttributes != null
+          && transparencyAttributes.getTransparency() > 0
+          && !ignoreTransparency) {
+        transparency = 1 - transparencyAttributes.getTransparency();
+      } else {
+        transparency = 1;
+      }
+      
+      TransparentTextureKey key = new TransparentTextureKey(texture, transparency);      
+      String imagePath = this.textureImagesCache.get(key);
       if (imagePath == null) {
-        ImageComponent2D imageComponent = (ImageComponent2D)texture.getImage(0);
-        RenderedImage image = imageComponent.getRenderedImage();
-        String fileFormat = texture.getFormat() == Texture.RGBA 
-            ? "png"
-            : "jpg";
-        File imageFile = OperatingSystem.createTemporaryFile("texture", "." + fileFormat);
-        ImageIO.write(image, fileFormat, imageFile);
-        imagePath = imageFile.getAbsolutePath();
-        this.textureImagesCache.put(texture, imagePath);
+        if (texture.getUserData() instanceof URL && transparency == 1) {
+          imagePath = texture.getUserData().toString();
+        } else {
+          ImageComponent2D imageComponent = (ImageComponent2D)texture.getImage(0);
+          RenderedImage image = imageComponent.getRenderedImage();
+          if (transparency < 1) {
+            // Compute a partially transparent image
+            BufferedImage transparentImage = new BufferedImage(image.getWidth(), 
+                image.getHeight(), BufferedImage.TYPE_INT_ARGB);
+            Graphics2D g2D = (Graphics2D)transparentImage.getGraphics();
+            g2D.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, transparency));
+            g2D.drawRenderedImage(image, null);
+            g2D.dispose();
+            image = transparentImage;
+          }
+          File imageFile = OperatingSystem.createTemporaryFile("texture", ".png");
+          ImageIO.write(image, "png", imageFile);
+          imagePath = imageFile.getAbsolutePath();
+        }
+        this.textureImagesCache.put(key, imagePath);
       }
       Material material = appearance.getMaterial();
       float shininess;
@@ -1196,11 +1218,14 @@ public class PhotoRenderer {
             this.sunflow.parameter("eta", 1.55f);
           }
           float transparency = 1 - transparencyAttributes.getTransparency();
-          this.sunflow.parameter("color", null, 
-              new float [] {transparency + (1 - transparency) * (float)Math.sqrt(diffuseColor [0]), 
-                            transparency + (1 - transparency) * (float)Math.sqrt(diffuseColor [1]), 
-                            transparency + (1 - transparency) * (float)Math.sqrt(diffuseColor [2])});
-          this.sunflow.parameter("transparency", transparency);
+          this.sunflow.parameter("color", null,
+              new float [] {(1 - transparency) + transparency * diffuseColor [0], 
+                            (1 - transparency) + transparency * diffuseColor [1], 
+                            (1 - transparency) + transparency * diffuseColor [2]});
+          this.sunflow.parameter("absorption.color", null, 
+              new float [] {transparency * (1 - diffuseColor [0]), 
+                            transparency * (1 - diffuseColor [1]), 
+                            transparency * (1 - diffuseColor [2])});
           this.sunflow.shader(appearanceName, "glass");
         } else if (material.getLightingEnable()
                    || ignoreConstantShader) {  
@@ -1384,4 +1409,28 @@ public class PhotoRenderer {
       return false;
     }
   }
+  
+  /**
+   * A key used to manage textures at different levels of transparency. 
+   */
+  private static class TransparentTextureKey {
+    private Texture texture;
+    private float   transparency;
+
+    public TransparentTextureKey(Texture texture, float transparency) {
+      this.texture = texture;
+      this.transparency = transparency;
+    }
+    
+    @Override
+    public boolean equals(Object obj) {
+      return ((TransparentTextureKey)obj).texture.equals(this.texture) 
+          && ((TransparentTextureKey)obj).transparency == this.transparency;
+    }
+    
+    @Override
+    public int hashCode() {
+      return this.texture.hashCode() + Float.floatToIntBits(this.transparency);
+    }
+  }
 }
