@@ -1,7 +1,7 @@
 /*
  * FurnitureCatalogListPanel.java 10 janv 2010
  *
- * Copyright (c) 2010 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2010 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -298,7 +298,7 @@ public class FurnitureCatalogListPanel extends JPanel implements View {
    * Language and catalog listener bound to this component with a weak reference to avoid
    * strong link between preferences and this component.  
    */
-  public static class PreferencesChangeListener implements PropertyChangeListener, CollectionListener<CatalogPieceOfFurniture> {
+  private static class PreferencesChangeListener implements PropertyChangeListener, CollectionListener<CatalogPieceOfFurniture> {
     private final WeakReference<FurnitureCatalogListPanel> furnitureCatalogPanel;
 
     public PreferencesChangeListener(FurnitureCatalogListPanel furnitureCatalogPanel) {
