@@ -1,7 +1,7 @@
 /*
  * HomeComponent3D.java 24 ao?t 2006
  *
- * Copyright (c) 2006 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2006 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ package com.eteks.sweethome3d.swing;
 import java.awt.AlphaComposite;
 import java.awt.Color;
 import java.awt.Component;
+import java.awt.ComponentOrientation;
 import java.awt.Composite;
 import java.awt.Container;
 import java.awt.Dimension;
@@ -82,6 +83,7 @@ import javax.media.j3d.Canvas3D;
 import javax.media.j3d.ColoringAttributes;
 import javax.media.j3d.DirectionalLight;
 import javax.media.j3d.Geometry;
+import javax.media.j3d.GraphicsConfigTemplate3D;
 import javax.media.j3d.Group;
 import javax.media.j3d.IllegalRenderingStateException;
 import javax.media.j3d.J3DGraphics2D;
@@ -140,6 +142,7 @@ import com.eteks.sweethome3d.model.Wall;
 import com.eteks.sweethome3d.tools.OperatingSystem;
 import com.eteks.sweethome3d.viewcontroller.HomeController3D;
 import com.eteks.sweethome3d.viewcontroller.Object3DFactory;
+import com.sun.j3d.exp.swing.JCanvas3D;
 import com.sun.j3d.utils.geometry.GeometryInfo;
 import com.sun.j3d.utils.universe.SimpleUniverse;
 import com.sun.j3d.utils.universe.Viewer;
@@ -160,7 +163,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   private final Object3DFactory                    object3dFactory;
   private final Map<Selectable, Object3DBranch>    homeObjects = new HashMap<Selectable, Object3DBranch>();
   private Collection<Selectable>                   homeObjectsToUpdate;
-  private Canvas3D                                 canvas3D;
+  private Component                                component3D;
   private SimpleUniverse                           onscreenUniverse;
   private Camera                                   camera;
   // Listeners bound to home that updates 3D scene objects
@@ -261,7 +264,18 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
     this.displayShadowOnFloor = displayShadowOnFloor;
     this.object3dFactory = object3DFactory;
 
-    this.canvas3D = Component3DManager.getInstance().getOnscreenCanvas3D(new Component3DManager.RenderingObserver() {        
+    if (Boolean.valueOf(System.getProperty("com.eteks.sweethome3d.j3d.useOffScreen3DView", "false"))) {
+      GraphicsConfigTemplate3D gc = new GraphicsConfigTemplate3D();
+      gc.setSceneAntialiasing(GraphicsConfigTemplate3D.PREFERRED);
+      this.component3D = new JCanvas3D(gc) {
+          public void paintComponent(Graphics g) {
+            super.paintComponent(g);
+            g.drawImage(navigationPanelImage, 0, 0, this);
+          }
+        };
+      this.component3D.setSize(1, 1);
+    } else {
+      this.component3D = Component3DManager.getInstance().getOnscreenCanvas3D(new Component3DManager.RenderingObserver() {        
         public void canvas3DSwapped(Canvas3D canvas3D) {
         }
         
@@ -279,7 +293,8 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
             g2D.flush(true);
           }
         }
-      });   
+      });
+    }
     JPanel canvasPanel = new JPanel(new LayoutManager() {
         public void addLayoutComponent(String name, Component comp) {
         }
@@ -288,15 +303,15 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
         }
         
         public Dimension preferredLayoutSize(Container parent) {
-          return canvas3D.getPreferredSize();
+          return component3D.getPreferredSize();
         }
         
         public Dimension minimumLayoutSize(Container parent) {
-          return canvas3D.getMinimumSize();
+          return component3D.getMinimumSize();
         }
         
         public void layoutContainer(Container parent) {
-          canvas3D.setBounds(0, 0, parent.getWidth(), parent.getHeight());
+          component3D.setBounds(0, 0, Math.max(1, parent.getWidth()), Math.max(1, parent.getHeight()));
           if (navigationPanel != null 
               && navigationPanel.isVisible()) {
             // Ensure that navigationPanel is always in top corner             
@@ -305,12 +320,13 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
           }
         }
       });
-    canvasPanel.add(this.canvas3D);    
+    
+    canvasPanel.add(this.component3D);    
     setLayout(new GridLayout());
     add(canvasPanel);
 
     if (controller != null) {
-      addMouseListeners(controller, this.canvas3D);
+      addMouseListeners(controller, this.component3D);
       if (preferences != null
           && (!OperatingSystem.isMacOSX()
               || OperatingSystem.isMacOSXLeopardOrSuperior())) {
@@ -330,14 +346,14 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
 
     // Add an ancestor listener to create canvas universe once this component is made visible 
     // and clean up universe once its parent frame is disposed
-    addAncestorListener(this.canvas3D, displayShadowOnFloor);
+    addAncestorListener(this.component3D, displayShadowOnFloor);
   }
 
   /**
    * Adds an ancestor listener to this component to manage canvas universe 
    * creation and clean up.  
    */
-  private void addAncestorListener(final Canvas3D canvas3D,
+  private void addAncestorListener(final Component component3D,
                                    final boolean displayShadowOnFloor) {
     addAncestorListener(new AncestorListener() {        
         public void ancestorAdded(AncestorEvent event) {
@@ -346,8 +362,10 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
           }
           onscreenUniverse = createUniverse(displayShadowOnFloor, true, false);
           // Bind universe to canvas3D
-          onscreenUniverse.getViewer().getView().addCanvas3D(canvas3D);
-          canvas3D.setFocusable(false);
+          onscreenUniverse.getViewer().getView().addCanvas3D(component3D instanceof Canvas3D
+              ? (Canvas3D)component3D
+              : ((JCanvas3D)component3D).getOffscreenCanvas3D());
+          component3D.setFocusable(false);
           updateNavigationPanelImage();
         }
         
@@ -367,7 +385,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   @Override
   public void setVisible(boolean visible) {
     super.setVisible(visible);
-    this.canvas3D.setVisible(visible);
+    this.component3D.setVisible(visible);
   }
   
   /**
@@ -400,7 +418,12 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   private JComponent createNavigationPanel(Home home, 
                                            UserPreferences preferences, 
                                            HomeController3D controller) {
-    JPanel navigationPanel = new JPanel(new GridBagLayout());
+    JPanel navigationPanel = new JPanel(new GridBagLayout()) {
+        @Override
+        public void applyComponentOrientation(ComponentOrientation o) {
+          // Ignore orientation
+        }
+      };
     String navigationPanelIconPath = preferences.getLocalizedString(HomeComponent3D.class, "navigationPanel.icon");
     final ImageIcon nagivationPanelIcon = navigationPanelIconPath.length() > 0
         ? new ImageIcon(HomeComponent3D.class.getResource(navigationPanelIconPath))
@@ -525,6 +548,14 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
       setFocusable(false);
       setBorder(null);
       setContentAreaFilled(false);
+      // Force preferred size to ensure button isn't larger
+      setPreferredSize(new Dimension(getIcon().getIconWidth(), getIcon().getIconHeight()));
+      addPropertyChangeListener(JButton.ICON_CHANGED_PROPERTY, new PropertyChangeListener() {
+          public void propertyChange(PropertyChangeEvent ev) {
+            // Reset border when icon is reset after a resource action change 
+            setBorder(null);
+          }
+        });
     }
   }
 
@@ -551,8 +582,8 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
           };
         this.navigationPanel.addComponentListener(this.navigationPanelListener);
         // Add the navigation panel to this component to be able to paint it 
-        // but show it behind heavyweight canvas 3D
-        this.canvas3D.getParent().add(this.navigationPanel);    
+        // but show it behind canvas 3D
+        this.component3D.getParent().add(this.navigationPanel);    
       } else {
         this.navigationPanel.removeComponentListener(this.navigationPanelListener);
         if (this.navigationPanel.getParent() != null) {
@@ -561,7 +592,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
       }
       revalidate();
       updateNavigationPanelImage();          
-      this.canvas3D.repaint();
+      this.component3D.repaint();
     }
   }
   
@@ -573,7 +604,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
     if (this.navigationPanel != null 
         && this.navigationPanel.isVisible()) {
       Rectangle componentBounds = this.navigationPanel.getBounds();
-      Rectangle imageSize = new Rectangle(this.canvas3D.getX(), this.canvas3D.getY());
+      Rectangle imageSize = new Rectangle(this.component3D.getX(), this.component3D.getY());
       imageSize.add(componentBounds.x + componentBounds.width, 
           componentBounds.y + componentBounds.height);
       if (!imageSize.isEmpty()) {
@@ -985,9 +1016,9 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   }
 
   /**
-   * Adds AWT mouse listeners to <code>canvas3D</code> that calls back <code>controller</code> methods.  
+   * Adds AWT mouse listeners to <code>component3D</code> that calls back <code>controller</code> methods.  
    */
-  private void addMouseListeners(final HomeController3D controller, final Component canvas3D) {
+  private void addMouseListeners(final HomeController3D controller, final Component component3D) {
     MouseInputAdapter mouseListener = new MouseInputAdapter() {
         private int        xLastMouseMove;
         private int        yLastMouseMove;
@@ -1135,7 +1166,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
           ev.getComponent().dispatchEvent(ev);
           if (!RepaintManager.currentManager(ev.getComponent()).getDirtyRegion((JComponent)ev.getComponent()).isEmpty()) {
             updateNavigationPanelImage();
-            canvas3D.repaint();
+            component3D.repaint();
             return true;
           }
           return false;
@@ -1164,9 +1195,9 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
         }
       };
     
-    canvas3D.addMouseListener(mouseListener);
-    canvas3D.addMouseMotionListener(mouseListener);
-    canvas3D.addMouseWheelListener(mouseWheelListener);
+    component3D.addMouseListener(mouseListener);
+    component3D.addMouseMotionListener(mouseListener);
+    component3D.addMouseWheelListener(mouseWheelListener);
     // Add a mouse listener to this component to request focus in case user clicks in component border
     this.addMouseListener(new MouseInputAdapter() {
         @Override
@@ -1283,7 +1314,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
     BranchGroup root = new BranchGroup();
     // Build scene tree
     root.addChild(createHomeTree(displayShadowOnFloor, listenToHomeUpdates, waitForLoading));
-    root.addChild(createBackgroundNode(listenToHomeUpdates));
+    root.addChild(createBackgroundNode(listenToHomeUpdates, waitForLoading));
     root.addChild(createGroundNode(-1E5f / 2, -1E5f / 2, 1E5f, 1E5f, listenToHomeUpdates, waitForLoading));
 
     // Add default lights
@@ -1297,7 +1328,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   /**
    * Returns a new background node.  
    */
-  private Node createBackgroundNode(boolean listenToHomeUpdates) {
+  private Node createBackgroundNode(boolean listenToHomeUpdates, final boolean waitForLoading) {
     final Appearance backgroundAppearance = new Appearance();
     ColoringAttributes backgroundColoringAttributes = new ColoringAttributes();
     backgroundAppearance.setColoringAttributes(backgroundColoringAttributes);
@@ -1312,7 +1343,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
     backgroundBranch.addChild(halfSphere);
     
     final Background background = new Background(backgroundBranch);
-    updateBackgroundColorAndTexture(backgroundAppearance, this.home);
+    updateBackgroundColorAndTexture(backgroundAppearance, this.home, waitForLoading);
     background.setImageScaleMode(Background.SCALE_FIT_ALL);
     background.setApplicationBounds(new BoundingBox(
         new Point3d(-1E6, -1E6, -1E6), 
@@ -1322,7 +1353,7 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
       // Add a listener on sky color and texture properties change 
       this.skyColorListener = new PropertyChangeListener() {
           public void propertyChange(PropertyChangeEvent ev) {
-            updateBackgroundColorAndTexture(backgroundAppearance, home);
+            updateBackgroundColorAndTexture(backgroundAppearance, home, waitForLoading);
           }
         };
       this.home.getEnvironment().addPropertyChangeListener(
@@ -1384,18 +1415,24 @@ public class HomeComponent3D extends JComponent implements com.eteks.sweethome3d
   /**
    * Updates<code>backgroundAppearance</code> color and texture from <code>home</code> sky color and texture.
    */
-  private void updateBackgroundColorAndTexture(final Appearance backgroundAppearance, Home home) {
+  private void updateBackgroundColorAndTexture(final Appearance backgroundAppearance, Home home, 
+                                               boolean waitForLoading) {
     Color3f skyColor = new Color3f(new Color(home.getEnvironment().getSkyColor()));
     backgroundAppearance.getColoringAttributes().setColor(skyColor);
     HomeTexture skyTexture = home.getEnvironment().getSkyTexture();
     if (skyTexture != null) {
-      final TextureManager imageManager = TextureManager.getInstance();
-      imageManager.loadTexture(skyTexture.getImage(), 
-          new TextureManager.TextureObserver() {
-              public void textureUpdated(Texture texture) {
-                backgroundAppearance.setTexture(texture);
-              }
-            });
+      TextureManager textureManager = TextureManager.getInstance();
+      if (waitForLoading) {
+        // Don't share the background texture otherwise if might not be rendered correctly
+        backgroundAppearance.setTexture(textureManager.loadTexture(skyTexture.getImage()));
+      } else {
+        textureManager.loadTexture(skyTexture.getImage(), waitForLoading, 
+            new TextureManager.TextureObserver() {
+                public void textureUpdated(Texture texture) {
+                  backgroundAppearance.setTexture(texture);
+                }
+              });
+      }
     } else {
       backgroundAppearance.setTexture(null);
     }
