@@ -1,7 +1,7 @@
 /*
  * PageSetupPanel.java 27 aout 07
  *
- * Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -282,7 +282,12 @@ public class PageSetupPanel extends JPanel implements DialogView {
   private void updateComponents(HomePrint homePrint) {
     this.pageFormat = HomePrintableComponent.getPageFormat(homePrint);
     // Check if off screen image is supported 
-    boolean offscreenCanvas3DSupported = Component3DManager.getInstance().isOffScreenImageSupported();
+    boolean offscreenCanvas3DSupported;
+    if ("true".equalsIgnoreCase(System.getProperty("com.eteks.sweethome3d.no3D"))) {
+      offscreenCanvas3DSupported = false;
+    } else { 
+      offscreenCanvas3DSupported = Component3DManager.getInstance().isOffScreenImageSupported();
+    }
     final NullableSpinnerNumberModel userPlanScaleSpinnerModel = 
         (NullableSpinner.NullableSpinnerNumberModel)this.userPlanScaleSpinner.getModel();
     if (homePrint != null) {
@@ -319,6 +324,7 @@ public class PageSetupPanel extends JPanel implements DialogView {
       this.footerFormatTextField.setText("");
     }
     this.view3DPrintedCheckBox.setEnabled(offscreenCanvas3DSupported);
+    this.view3DPrintedCheckBox.setVisible(!"true".equalsIgnoreCase(System.getProperty("com.eteks.sweethome3d.no3D")));
   }
 
   /**
