@@ -1,7 +1,7 @@
 /*
  * SwingTools.java 21 oct. 2008
  *
- * Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -203,11 +203,15 @@ public class SwingTools {
     feedbackComponent.setBorder(unfocusedViewBorder);
     component.addFocusListener(new FocusListener() {
         public void focusLost(FocusEvent ev) {
-          feedbackComponent.setBorder(unfocusedViewBorder);
+          if (feedbackComponent.getBorder() == focusedViewBorder) {
+            feedbackComponent.setBorder(unfocusedViewBorder);
+          }
         }
         
         public void focusGained(FocusEvent ev) {
-          feedbackComponent.setBorder(focusedViewBorder);
+          if (feedbackComponent.getBorder() == unfocusedViewBorder) {
+            feedbackComponent.setBorder(focusedViewBorder);
+          }
         }
       });
   }
@@ -354,7 +358,11 @@ public class SwingTools {
                                       final JComponent focusedComponent) {
     JOptionPane optionPane = new JOptionPane(messageComponent, 
         JOptionPane.PLAIN_MESSAGE, JOptionPane.OK_CANCEL_OPTION);
-    final JDialog dialog = optionPane.createDialog(SwingUtilities.getRootPane(parentComponent), title);
+    parentComponent = SwingUtilities.getRootPane(parentComponent);
+    if (parentComponent != null) {
+      optionPane.setComponentOrientation(parentComponent.getComponentOrientation());
+    }
+    final JDialog dialog = optionPane.createDialog(parentComponent, title);
     if (focusedComponent != null) {
       // Add a listener that transfer focus to focusedComponent when dialog is shown
       dialog.addComponentListener(new ComponentAdapter() {
@@ -384,9 +392,12 @@ public class SwingTools {
                                        String title,
                                        int messageType,
                                        final JComponent focusedComponent) {
-    JOptionPane optionPane = new JOptionPane(messageComponent, 
-        messageType, JOptionPane.DEFAULT_OPTION);
-    final JDialog dialog = optionPane.createDialog(SwingUtilities.getRootPane(parentComponent), title);
+    JOptionPane optionPane = new JOptionPane(messageComponent, messageType, JOptionPane.DEFAULT_OPTION);
+    parentComponent = SwingUtilities.getRootPane(parentComponent);
+    if (parentComponent != null) {
+      optionPane.setComponentOrientation(parentComponent.getComponentOrientation());
+    }
+    final JDialog dialog = optionPane.createDialog(parentComponent, title);
     if (focusedComponent != null) {
       // Add a listener that transfer focus to focusedComponent when dialog is shown
       dialog.addComponentListener(new ComponentAdapter() {
