@@ -1,7 +1,7 @@
 /*
  * SwingViewFactory.java 28 oct. 2008
  *
- * Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2008 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -97,7 +97,11 @@ public class SwingViewFactory implements ViewFactory {
    */
   public View createView3D(Home home, UserPreferences preferences,
                            HomeController3D homeController3D) {
-    return new HomeComponent3D(home, preferences, homeController3D);
+    if ("true".equalsIgnoreCase(System.getProperty("com.eteks.sweethome3d.no3D"))) {
+      return null;
+    } else {
+      return new HomeComponent3D(home, preferences, homeController3D);
+    }
   }
 
   /**
