@@ -1,7 +1,7 @@
 /*
  * VideoPanel.java 15 fevr. 2010
  *
- * Copyright (c) 2010 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2010 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,6 +77,7 @@ import java.util.GregorianCalendar;
 import java.util.Hashtable;
 import java.util.List;
 import java.util.ListIterator;
+import java.util.Locale;
 import java.util.TimeZone;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
@@ -650,8 +651,36 @@ public class VideoPanel extends JPanel implements DialogView {
     final SpinnerDateModel timeSpinnerModel = new SpinnerDateModel();
     timeSpinnerModel.setValue(time);
     this.timeSpinner = new JSpinner(timeSpinnerModel);
-    JSpinner.DateEditor timeEditor = new JSpinner.DateEditor(this.timeSpinner, 
-        ((SimpleDateFormat)DateFormat.getTimeInstance(DateFormat.SHORT)).toPattern());
+    // From http://en.wikipedia.org/wiki/12-hour_clock#Use_by_country
+    String [] twelveHoursCountries = { 
+        "AU",  // Australia
+        "BD",  // Bangladesh
+        "CA",  // Canada (excluding Quebec, in French)
+        "CO",  // Colombia
+        "EG",  // Egypt
+        "HN",  // Honduras
+        "JO",  // Jordan
+        "MX",  // Mexico
+        "MY",  // Malaysia
+        "NI",  // Nicaragua
+        "NZ",  // New Zealand
+        "PH",  // Philippines
+        "PK",  // Pakistan
+        "SA",  // Saudi Arabia
+        "SV",  // El Salvador
+        "US",  // United States
+        "VE"}; // Venezuela         
+    SimpleDateFormat timeInstance;
+    if ("en".equals(Locale.getDefault().getLanguage())) {
+      if (Arrays.binarySearch(twelveHoursCountries, Locale.getDefault().getCountry()) >= 0) {
+        timeInstance = (SimpleDateFormat)DateFormat.getTimeInstance(DateFormat.SHORT, Locale.US); // 12 hours notation
+      } else {
+        timeInstance = (SimpleDateFormat)DateFormat.getTimeInstance(DateFormat.SHORT, Locale.UK); // 24 hours notation
+      }
+    } else {
+      timeInstance = (SimpleDateFormat)DateFormat.getTimeInstance(DateFormat.SHORT);
+    }
+    JSpinner.DateEditor timeEditor = new JSpinner.DateEditor(this.timeSpinner, timeInstance.toPattern());
     this.timeSpinner.setEditor(timeEditor);
     SwingTools.addAutoSelectionOnFocusGain(timeEditor.getTextField());
 
@@ -741,7 +770,7 @@ public class VideoPanel extends JPanel implements DialogView {
               VideoPanel.class, "bestLabel.text")).getPreferredSize().width / 2;
     int sliderWidth = qualitySlider.getWidth() - fastLabelOffset - bestLabelOffset;
     return qualitySlider.getMinimum()
-        + (float)(x - (qualitySlider.getComponentOrientation() == ComponentOrientation.LEFT_TO_RIGHT 
+        + (float)(x - (qualitySlider.getComponentOrientation().isLeftToRight() 
                           ? fastLabelOffset 
                           : bestLabelOffset))
         / sliderWidth * (qualitySlider.getMaximum() - qualitySlider.getMinimum());
@@ -825,6 +854,7 @@ public class VideoPanel extends JPanel implements DialogView {
       if (videoPanel == null) {
         preferences.removePropertyChangeListener(UserPreferences.Property.LANGUAGE, this);
       } else {
+        videoPanel.setComponentOrientation(ComponentOrientation.getOrientation(Locale.getDefault()));
         videoPanel.setComponentTexts(preferences);
         videoPanel.setMnemonics(preferences);
       }
@@ -948,6 +978,9 @@ public class VideoPanel extends JPanel implements DialogView {
       final JOptionPane optionPane = new JOptionPane(this, 
           JOptionPane.PLAIN_MESSAGE, JOptionPane.OK_CANCEL_OPTION,
           null, new Object [] {this.createButton, this.saveButton, this.closeButton}, this.createButton);
+      if (parentView != null) {
+        optionPane.setComponentOrientation(((JComponent)parentView).getComponentOrientation());
+      }
       final JDialog dialog = optionPane.createDialog(SwingUtilities.getRootPane((Component)parentView), this.dialogTitle);
       dialog.setModal(false);
       
