@@ -1,7 +1,7 @@
 /*
  * HelpController.java 20 juil. 07
  *
- * Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2007 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -333,6 +333,12 @@ public class HelpController implements Controller {
     URL helpIndex = getHelpIndexPageURL();
     String [] searchedWords = getLowerCaseSearchedWords(searchedText);
     List<HelpDocument> helpDocuments = searchInHelpDocuments(helpIndex, searchedWords);
+    URL applicationIconUrl = null;
+    try {
+      applicationIconUrl = new ResourceURLContent(HelpController.class, "resources/help/images/applicationIcon32.png").getURL();
+    } catch (Exception ex) {
+      // Ignore icon
+    }
     // Build dynamically the search result page
     final StringBuilder htmlText = new StringBuilder(
         "<html><head><meta http-equiv='content-type' content='text/html;charset=UTF-8'><link href='" 
@@ -346,9 +352,9 @@ public class HelpController implements Controller {
         + "  <table width='100%' border='0' cellspacing='0' cellpadding='0'>"
         + "    <tr valign='bottom' height='32'>"
         + "      <td width='3' height='32'>&nbsp;</td>"
-        + "      <td width='32' height='32'><img src='"  
-        + new ResourceURLContent(HelpController.class, "resources/help/images/applicationIcon32.png").getURL() 
-        + "' height='32' width='32'></td>"
+        + (applicationIconUrl != null 
+              ? "<td width='32' height='32'><img src='" + applicationIconUrl + "' height='32' width='32'></td>" 
+              : "")
         + "      <td width='8' height='32'>&nbsp;&nbsp;</td>"
         + "      <td valign='bottom' height='32'><font id='topic'>" 
         +            this.preferences.getLocalizedString(HelpController.class, "searchResult") + "</font></td>"
@@ -419,7 +425,7 @@ public class HelpController implements Controller {
    * This method uses some Swing classes for their HTML parsing capabilities 
    * and not to create components.
    */
-  public List<HelpDocument> searchInHelpDocuments(URL helpIndex, String [] searchedWords) {
+  private List<HelpDocument> searchInHelpDocuments(URL helpIndex, String [] searchedWords) {
     List<URL> parsedDocuments = new ArrayList<URL>(); 
     parsedDocuments.add(helpIndex);
     
@@ -459,7 +465,7 @@ public class HelpController implements Controller {
   /**
    * A help HTML document parsed with <code>HTMLEditorKit</code>. 
    */
-  private static class HelpDocument extends HTMLDocument {
+  private class HelpDocument extends HTMLDocument {
     // Documents set referenced in this file 
     private Set<URL>     referencedDocuments = new HashSet<URL>();
     private String []    searchedWords;
@@ -519,8 +525,8 @@ public class HelpController implements Controller {
     
     private void addReferencedDocument(String referencedDocument) {
       try {        
-        if (!referencedDocument.startsWith("http:")) {
-          URL url = new URL(getBase(), referencedDocument);
+        URL url = new URL(getBase(), referencedDocument);
+        if (!isBrowserPage(url)) {
           URL urlWithNoAnchor = new URL(
               url.getProtocol(), url.getHost(), url.getPort(), url.getFile());
           this.referencedDocuments.add(urlWithNoAnchor);
