@@ -1,7 +1,7 @@
 /*
  * PhotoController.java 5 mai 2009
  *
- * Copyright (c) 2009 Emmanuel PUYBARET / eTeks <info@eteks.com>. All Rights Reserved.
+ * Sweet Home 3D, Copyright (c) 2009 Emmanuel PUYBARET / eTeks <info@eteks.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -95,7 +95,7 @@ public class PhotoController implements Controller {
       } else {
         ((Camera)ev.getOldValue()).removePropertyChangeListener(controller.cameraChangeListener);
         controller.updateProperties();
-        ((Camera)ev.getNewValue()).removePropertyChangeListener(controller.cameraChangeListener);
+        ((Camera)ev.getNewValue()).addPropertyChangeListener(controller.cameraChangeListener);
       }
     }
   }
